# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/datatransfer/v1/endpoint/kafka.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.datatransfer.v1.endpoint import common_pb2 as yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2
from yandex.cloud.datatransfer.v1.endpoint import parsers_pb2 as yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_parsers__pb2
from yandex.cloud.datatransfer.v1.endpoint import serializers_pb2 as yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_serializers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1yandex/cloud/datatransfer/v1/endpoint/kafka.proto\x12%yandex.cloud.datatransfer.v1.endpoint\x1a\x32yandex/cloud/datatransfer/v1/endpoint/common.proto\x1a\x33yandex/cloud/datatransfer/v1/endpoint/parsers.proto\x1a\x37yandex/cloud/datatransfer/v1/endpoint/serializers.proto\"\x89\x01\n\x16KafkaConnectionOptions\x12\x14\n\ncluster_id\x18\x01 \x01(\tH\x00\x12K\n\non_premise\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.datatransfer.v1.endpoint.OnPremiseKafkaH\x00\x42\x0c\n\nconnection\"\x80\x01\n\x0eOnPremiseKafka\x12\x13\n\x0b\x62roker_urls\x18\x01 \x03(\t\x12\x11\n\tsubnet_id\x18\x04 \x01(\t\x12@\n\x08tls_mode\x18\x05 \x01(\x0b\x32..yandex.cloud.datatransfer.v1.endpoint.TLSModeJ\x04\x08\x02\x10\x04\"\xa3\x01\n\tKafkaAuth\x12H\n\x04sasl\x18\x01 \x01(\x0b\x32\x38.yandex.cloud.datatransfer.v1.endpoint.KafkaSaslSecurityH\x00\x12@\n\x07no_auth\x18\x02 \x01(\x0b\x32-.yandex.cloud.datatransfer.v1.endpoint.NoAuthH\x00\x42\n\n\x08security\"\xb2\x01\n\x11KafkaSaslSecurity\x12\x0c\n\x04user\x18\x01 \x01(\t\x12H\n\tmechanism\x18\x03 \x01(\x0e\x32\x35.yandex.cloud.datatransfer.v1.endpoint.KafkaMechanism\x12?\n\x08password\x18\x04 \x01(\x0b\x32-.yandex.cloud.datatransfer.v1.endpoint.SecretJ\x04\x08\x02\x10\x03\"\x82\x03\n\x0bKafkaSource\x12Q\n\nconnection\x18\x01 \x01(\x0b\x32=.yandex.cloud.datatransfer.v1.endpoint.KafkaConnectionOptions\x12>\n\x04\x61uth\x18\x02 \x01(\x0b\x32\x30.yandex.cloud.datatransfer.v1.endpoint.KafkaAuth\x12\x17\n\x0fsecurity_groups\x18\x03 \x03(\t\x12\x16\n\ntopic_name\x18\x04 \x01(\tB\x02\x18\x01\x12U\n\x0btransformer\x18\x05 \x01(\x0b\x32@.yandex.cloud.datatransfer.v1.endpoint.DataTransformationOptions\x12=\n\x06parser\x18\x07 \x01(\x0b\x32-.yandex.cloud.datatransfer.v1.endpoint.Parser\x12\x13\n\x0btopic_names\x18\x08 \x03(\tJ\x04\x08\x06\x10\x07\"\xdf\x02\n\x0bKafkaTarget\x12Q\n\nconnection\x18\x01 \x01(\x0b\x32=.yandex.cloud.datatransfer.v1.endpoint.KafkaConnectionOptions\x12>\n\x04\x61uth\x18\x02 \x01(\x0b\x32\x30.yandex.cloud.datatransfer.v1.endpoint.KafkaAuth\x12\x17\n\x0fsecurity_groups\x18\x03 \x03(\t\x12W\n\x0etopic_settings\x18\x07 \x01(\x0b\x32?.yandex.cloud.datatransfer.v1.endpoint.KafkaTargetTopicSettings\x12\x45\n\nserializer\x18\x08 \x01(\x0b\x32\x31.yandex.cloud.datatransfer.v1.endpoint.SerializerJ\x04\x08\x04\x10\x07\"\x8e\x01\n\x18KafkaTargetTopicSettings\x12H\n\x05topic\x18\x01 \x01(\x0b\x32\x37.yandex.cloud.datatransfer.v1.endpoint.KafkaTargetTopicH\x00\x12\x16\n\x0ctopic_prefix\x18\x02 \x01(\tH\x00\x42\x10\n\x0etopic_settings\"=\n\x10KafkaTargetTopic\x12\x12\n\ntopic_name\x18\x01 \x01(\t\x12\x15\n\rsave_tx_order\x18\x02 \x01(\x08*i\n\x0eKafkaMechanism\x12\x1f\n\x1bKAFKA_MECHANISM_UNSPECIFIED\x10\x00\x12\x1a\n\x16KAFKA_MECHANISM_SHA256\x10\x01\x12\x1a\n\x16KAFKA_MECHANISM_SHA512\x10\x02\x42\xa7\x01\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\xaa\x02%Yandex.Cloud.Datatransfer.V1.EndPointb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.datatransfer.v1.endpoint.kafka_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\252\002%Yandex.Cloud.Datatransfer.V1.EndPoint'
  _KAFKASOURCE.fields_by_name['topic_name']._options = None
  _KAFKASOURCE.fields_by_name['topic_name']._serialized_options = b'\030\001'
  _globals['_KAFKAMECHANISM']._serialized_start=1823
  _globals['_KAFKAMECHANISM']._serialized_end=1928
  _globals['_KAFKACONNECTIONOPTIONS']._serialized_start=255
  _globals['_KAFKACONNECTIONOPTIONS']._serialized_end=392
  _globals['_ONPREMISEKAFKA']._serialized_start=395
  _globals['_ONPREMISEKAFKA']._serialized_end=523
  _globals['_KAFKAAUTH']._serialized_start=526
  _globals['_KAFKAAUTH']._serialized_end=689
  _globals['_KAFKASASLSECURITY']._serialized_start=692
  _globals['_KAFKASASLSECURITY']._serialized_end=870
  _globals['_KAFKASOURCE']._serialized_start=873
  _globals['_KAFKASOURCE']._serialized_end=1259
  _globals['_KAFKATARGET']._serialized_start=1262
  _globals['_KAFKATARGET']._serialized_end=1613
  _globals['_KAFKATARGETTOPICSETTINGS']._serialized_start=1616
  _globals['_KAFKATARGETTOPICSETTINGS']._serialized_end=1758
  _globals['_KAFKATARGETTOPIC']._serialized_start=1760
  _globals['_KAFKATARGETTOPIC']._serialized_end=1821
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.apploadbalancer.v1.target_group_pb2
import yandex.cloud.operation.operation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetTargetGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARGET_GROUP_ID_FIELD_NUMBER: builtins.int
    target_group_id: builtins.str
    """ID of the target group to return.

    To get the target group ID, make a [TargetGroupService.List] request.
    """
    def __init__(
        self,
        *,
        target_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["target_group_id", b"target_group_id"]) -> None: ...

global___GetTargetGroupRequest = GetTargetGroupRequest

@typing.final
class ListTargetGroupsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list target groups in.

    To get the folder ID, make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `page_size`, the service returns a [ListTargetGroupsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListTargetGroupsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters target groups listed in the response.

    The expression must specify:
    1. The field name. Currently you can use filtering only on [TargetGroup.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    Example of a filter: `name=my-target-group`.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListTargetGroupsRequest = ListTargetGroupsRequest

@typing.final
class ListTargetGroupsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARGET_GROUPS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListTargetGroupsRequest.page_size], use `next_page_token` as the value
    for the [ListTargetGroupsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def target_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.apploadbalancer.v1.target_group_pb2.TargetGroup]:
        """List of target groups in the specified folder."""

    def __init__(
        self,
        *,
        target_groups: collections.abc.Iterable[yandex.cloud.apploadbalancer.v1.target_group_pb2.TargetGroup] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "target_groups", b"target_groups"]) -> None: ...

global___ListTargetGroupsResponse = ListTargetGroupsResponse

@typing.final
class DeleteTargetGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARGET_GROUP_ID_FIELD_NUMBER: builtins.int
    target_group_id: builtins.str
    """ID of the target group to delete.

    To get the target group ID, make a [TargetGroupService.List] request.
    """
    def __init__(
        self,
        *,
        target_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["target_group_id", b"target_group_id"]) -> None: ...

global___DeleteTargetGroupRequest = DeleteTargetGroupRequest

@typing.final
class DeleteTargetGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARGET_GROUP_ID_FIELD_NUMBER: builtins.int
    target_group_id: builtins.str
    """ID of the target group that is being deleted."""
    def __init__(
        self,
        *,
        target_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["target_group_id", b"target_group_id"]) -> None: ...

global___DeleteTargetGroupMetadata = DeleteTargetGroupMetadata

@typing.final
class UpdateTargetGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    TARGET_GROUP_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    TARGETS_FIELD_NUMBER: builtins.int
    target_group_id: builtins.str
    """ID of the target group to update.

    To get the target group ID, make a [TargetGroupService.List] request.
    """
    name: builtins.str
    """New name for the target group.
    The name must be unique within the folder.
    """
    description: builtins.str
    """New description of the target group."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which attributes of the target group should be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Target group labels as `key:value` pairs.
        For details about the concept, see [documentation](/docs/overview/concepts/services#labels).

        Existing set of labels is completely replaced by the provided set, so if you just want
        to add or remove a label:
        1. Get the current set of labels with a [TargetGroupService.Get] request.
        2. Add or remove a label in this set.
        3. Send the new set in this field.
        """

    @property
    def targets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.apploadbalancer.v1.target_group_pb2.Target]:
        """New list of targets in the target group.

        Existing list of targets is completely replaced by the specified list, so if you just want to add or remove
        a target, make a [TargetGroupService.AddTargets] request or a [TargetGroupService.RemoveTargets] request.
        """

    def __init__(
        self,
        *,
        target_group_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        targets: collections.abc.Iterable[yandex.cloud.apploadbalancer.v1.target_group_pb2.Target] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "labels", b"labels", "name", b"name", "target_group_id", b"target_group_id", "targets", b"targets", "update_mask", b"update_mask"]) -> None: ...

global___UpdateTargetGroupRequest = UpdateTargetGroupRequest

@typing.final
class UpdateTargetGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARGET_GROUP_ID_FIELD_NUMBER: builtins.int
    target_group_id: builtins.str
    """ID of the target group that is being updated."""
    def __init__(
        self,
        *,
        target_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["target_group_id", b"target_group_id"]) -> None: ...

global___UpdateTargetGroupMetadata = UpdateTargetGroupMetadata

@typing.final
class CreateTargetGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    TARGETS_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a target group in.

    To get the folder ID, make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    name: builtins.str
    """Name of the target group.
    The name must be unique within the folder.
    """
    description: builtins.str
    """Description of the target group."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Target group labels as `key:value` pairs.
        For details about the concept, see [documentation](/docs/overview/concepts/services#labels).
        """

    @property
    def targets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.apploadbalancer.v1.target_group_pb2.Target]:
        """List of targets in the target group."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        targets: collections.abc.Iterable[yandex.cloud.apploadbalancer.v1.target_group_pb2.Target] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "folder_id", b"folder_id", "labels", b"labels", "name", b"name", "targets", b"targets"]) -> None: ...

global___CreateTargetGroupRequest = CreateTargetGroupRequest

@typing.final
class CreateTargetGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARGET_GROUP_ID_FIELD_NUMBER: builtins.int
    target_group_id: builtins.str
    """ID of the target group that is being created."""
    def __init__(
        self,
        *,
        target_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["target_group_id", b"target_group_id"]) -> None: ...

global___CreateTargetGroupMetadata = CreateTargetGroupMetadata

@typing.final
class AddTargetsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARGET_GROUP_ID_FIELD_NUMBER: builtins.int
    TARGETS_FIELD_NUMBER: builtins.int
    target_group_id: builtins.str
    """ID of the target group to add targets to.

    To get the target group ID, make a [TargetGroupService.List] request.
    """
    @property
    def targets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.apploadbalancer.v1.target_group_pb2.Target]:
        """List of targets to add to the target group."""

    def __init__(
        self,
        *,
        target_group_id: builtins.str = ...,
        targets: collections.abc.Iterable[yandex.cloud.apploadbalancer.v1.target_group_pb2.Target] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["target_group_id", b"target_group_id", "targets", b"targets"]) -> None: ...

global___AddTargetsRequest = AddTargetsRequest

@typing.final
class AddTargetsMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARGET_GROUP_ID_FIELD_NUMBER: builtins.int
    target_group_id: builtins.str
    """ID of the target group that the targets are being added to."""
    def __init__(
        self,
        *,
        target_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["target_group_id", b"target_group_id"]) -> None: ...

global___AddTargetsMetadata = AddTargetsMetadata

@typing.final
class RemoveTargetsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARGET_GROUP_ID_FIELD_NUMBER: builtins.int
    TARGETS_FIELD_NUMBER: builtins.int
    target_group_id: builtins.str
    """ID of the target group to remove targets from.

    To get the target group ID, make a [TargetGroupService.List] request.
    """
    @property
    def targets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.apploadbalancer.v1.target_group_pb2.Target]:
        """List of targets to remove from the target group."""

    def __init__(
        self,
        *,
        target_group_id: builtins.str = ...,
        targets: collections.abc.Iterable[yandex.cloud.apploadbalancer.v1.target_group_pb2.Target] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["target_group_id", b"target_group_id", "targets", b"targets"]) -> None: ...

global___RemoveTargetsRequest = RemoveTargetsRequest

@typing.final
class RemoveTargetsMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARGET_GROUP_ID_FIELD_NUMBER: builtins.int
    target_group_id: builtins.str
    """ID of the target group that the targets are being removed from."""
    def __init__(
        self,
        *,
        target_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["target_group_id", b"target_group_id"]) -> None: ...

global___RemoveTargetsMetadata = RemoveTargetsMetadata

@typing.final
class ListTargetGroupOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARGET_GROUP_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    target_group_id: builtins.str
    """ID of the target group to get operations for.

    To get the target group ID, use a [TargetGroupService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page that should be returned. If the number of available
    results is larger than [page_size], the service returns a [ListTargetGroupOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListTargetGroupOperationsResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        target_group_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token", "target_group_id", b"target_group_id"]) -> None: ...

global___ListTargetGroupOperationsRequest = ListTargetGroupOperationsRequest

@typing.final
class ListTargetGroupOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListTargetGroupOperationsRequest.page_size], use `next_page_token` as the value
    for the [ListTargetGroupOperationsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified target group."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListTargetGroupOperationsResponse = ListTargetGroupOperationsResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/containerregistry/v1/scanner.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/yandex/cloud/containerregistry/v1/scanner.proto\x12!yandex.cloud.containerregistry.v1\x1a\x1dyandex/cloud/validation.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb5\x02\n\nScanResult\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08image_id\x18\x02 \x01(\t\x12.\n\nscanned_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x44\n\x06status\x18\x04 \x01(\x0e\x32\x34.yandex.cloud.containerregistry.v1.ScanResult.Status\x12N\n\x0fvulnerabilities\x18\x05 \x01(\x0b\x32\x35.yandex.cloud.containerregistry.v1.VulnerabilityStats\"C\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0b\n\x07RUNNING\x10\x01\x12\t\n\x05READY\x10\x02\x12\t\n\x05\x45RROR\x10\x03\"x\n\x12VulnerabilityStats\x12\x10\n\x08\x63ritical\x18\x01 \x01(\x03\x12\x0c\n\x04high\x18\x02 \x01(\x03\x12\x0e\n\x06medium\x18\x03 \x01(\x03\x12\x0b\n\x03low\x18\x04 \x01(\x03\x12\x12\n\nnegligible\x18\x05 \x01(\x03\x12\x11\n\tundefined\x18\x06 \x01(\x03\"\xb1\x02\n\rVulnerability\x12K\n\x08severity\x18\x01 \x01(\x0e\x32\x39.yandex.cloud.containerregistry.v1.Vulnerability.Severity\x12J\n\x07package\x18\x02 \x01(\x0b\x32\x37.yandex.cloud.containerregistry.v1.PackageVulnerabilityH\x00\"p\n\x08Severity\x12\x18\n\x14SEVERITY_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43RITICAL\x10\x01\x12\x08\n\x04HIGH\x10\x02\x12\n\n\x06MEDIUM\x10\x03\x12\x07\n\x03LOW\x10\x04\x12\x0e\n\nNEGLIGIBLE\x10\x05\x12\r\n\tUNDEFINED\x10\x06\x42\x15\n\rvulnerability\x12\x04\xc0\xc1\x31\x01\"\x94\x01\n\x14PackageVulnerability\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04link\x18\x02 \x01(\t\x12\x0f\n\x07package\x18\x03 \x01(\t\x12\x0e\n\x06source\x18\x04 \x01(\t\x12\x0f\n\x07version\x18\x05 \x01(\t\x12\x10\n\x08\x66ixed_by\x18\x06 \x01(\t\x12\x0e\n\x06origin\x18\x07 \x01(\t\x12\x0c\n\x04type\x18\x08 \x01(\tB\x80\x01\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.containerregistry.v1.scanner_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistry'
  _VULNERABILITY.oneofs_by_name['vulnerability']._options = None
  _VULNERABILITY.oneofs_by_name['vulnerability']._serialized_options = b'\300\3011\001'
  _globals['_SCANRESULT']._serialized_start=151
  _globals['_SCANRESULT']._serialized_end=460
  _globals['_SCANRESULT_STATUS']._serialized_start=393
  _globals['_SCANRESULT_STATUS']._serialized_end=460
  _globals['_VULNERABILITYSTATS']._serialized_start=462
  _globals['_VULNERABILITYSTATS']._serialized_end=582
  _globals['_VULNERABILITY']._serialized_start=585
  _globals['_VULNERABILITY']._serialized_end=890
  _globals['_VULNERABILITY_SEVERITY']._serialized_start=755
  _globals['_VULNERABILITY_SEVERITY']._serialized_end=867
  _globals['_PACKAGEVULNERABILITY']._serialized_start=893
  _globals['_PACKAGEVULNERABILITY']._serialized_end=1041
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.mdb.clickhouse.v1.format_schema_pb2
import yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class FormatSchemaServiceStub:
    """A set of methods for managing [format schemas](https://clickhouse.com/docs/en/interfaces/formats) for input and output data."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2.GetFormatSchemaRequest,
        yandex.cloud.mdb.clickhouse.v1.format_schema_pb2.FormatSchema,
    ]
    """Returns detailed information about a given format schema."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2.ListFormatSchemasRequest,
        yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2.ListFormatSchemasResponse,
    ]
    """Returns a list of format schemas in a cluster."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2.CreateFormatSchemaRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Adds a format schema to a cluster."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2.UpdateFormatSchemaRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Changes a format schema."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2.DeleteFormatSchemaRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes a format schema from a cluster."""

class FormatSchemaServiceAsyncStub:
    """A set of methods for managing [format schemas](https://clickhouse.com/docs/en/interfaces/formats) for input and output data."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2.GetFormatSchemaRequest,
        yandex.cloud.mdb.clickhouse.v1.format_schema_pb2.FormatSchema,
    ]
    """Returns detailed information about a given format schema."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2.ListFormatSchemasRequest,
        yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2.ListFormatSchemasResponse,
    ]
    """Returns a list of format schemas in a cluster."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2.CreateFormatSchemaRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Adds a format schema to a cluster."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2.UpdateFormatSchemaRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Changes a format schema."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2.DeleteFormatSchemaRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes a format schema from a cluster."""

class FormatSchemaServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing [format schemas](https://clickhouse.com/docs/en/interfaces/formats) for input and output data."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2.GetFormatSchemaRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.clickhouse.v1.format_schema_pb2.FormatSchema, collections.abc.Awaitable[yandex.cloud.mdb.clickhouse.v1.format_schema_pb2.FormatSchema]]:
        """Returns detailed information about a given format schema."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2.ListFormatSchemasRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2.ListFormatSchemasResponse, collections.abc.Awaitable[yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2.ListFormatSchemasResponse]]:
        """Returns a list of format schemas in a cluster."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2.CreateFormatSchemaRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Adds a format schema to a cluster."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2.UpdateFormatSchemaRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Changes a format schema."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2.DeleteFormatSchemaRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes a format schema from a cluster."""

def add_FormatSchemaServiceServicer_to_server(servicer: FormatSchemaServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import yandex.cloud.datatransfer.v1.endpoint.common_pb2
import yandex.cloud.datatransfer.v1.endpoint.parsers_pb2
import yandex.cloud.datatransfer.v1.endpoint.serializers_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _KafkaMechanism:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _KafkaMechanismEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_KafkaMechanism.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    KAFKA_MECHANISM_UNSPECIFIED: _KafkaMechanism.ValueType  # 0
    KAFKA_MECHANISM_SHA256: _KafkaMechanism.ValueType  # 1
    KAFKA_MECHANISM_SHA512: _KafkaMechanism.ValueType  # 2

class KafkaMechanism(_KafkaMechanism, metaclass=_KafkaMechanismEnumTypeWrapper): ...

KAFKA_MECHANISM_UNSPECIFIED: KafkaMechanism.ValueType  # 0
KAFKA_MECHANISM_SHA256: KafkaMechanism.ValueType  # 1
KAFKA_MECHANISM_SHA512: KafkaMechanism.ValueType  # 2
global___KafkaMechanism = KafkaMechanism

@typing.final
class KafkaConnectionOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    ON_PREMISE_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """Managed Service for Kafka cluster ID"""
    @property
    def on_premise(self) -> global___OnPremiseKafka:
        """Connection options for on-premise Kafka"""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        on_premise: global___OnPremiseKafka | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "connection", b"connection", "on_premise", b"on_premise"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "connection", b"connection", "on_premise", b"on_premise"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["connection", b"connection"]) -> typing.Literal["cluster_id", "on_premise"] | None: ...

global___KafkaConnectionOptions = KafkaConnectionOptions

@typing.final
class OnPremiseKafka(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BROKER_URLS_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    TLS_MODE_FIELD_NUMBER: builtins.int
    subnet_id: builtins.str
    """Network interface for endpoint. If none will assume public ipv4"""
    @property
    def broker_urls(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Kafka broker URLs"""

    @property
    def tls_mode(self) -> yandex.cloud.datatransfer.v1.endpoint.common_pb2.TLSMode:
        """TLS settings for broker connection. Disabled by default."""

    def __init__(
        self,
        *,
        broker_urls: collections.abc.Iterable[builtins.str] | None = ...,
        subnet_id: builtins.str = ...,
        tls_mode: yandex.cloud.datatransfer.v1.endpoint.common_pb2.TLSMode | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["tls_mode", b"tls_mode"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["broker_urls", b"broker_urls", "subnet_id", b"subnet_id", "tls_mode", b"tls_mode"]) -> None: ...

global___OnPremiseKafka = OnPremiseKafka

@typing.final
class KafkaAuth(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SASL_FIELD_NUMBER: builtins.int
    NO_AUTH_FIELD_NUMBER: builtins.int
    @property
    def sasl(self) -> global___KafkaSaslSecurity:
        """Authentication with SASL"""

    @property
    def no_auth(self) -> yandex.cloud.datatransfer.v1.endpoint.common_pb2.NoAuth:
        """No authentication"""

    def __init__(
        self,
        *,
        sasl: global___KafkaSaslSecurity | None = ...,
        no_auth: yandex.cloud.datatransfer.v1.endpoint.common_pb2.NoAuth | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["no_auth", b"no_auth", "sasl", b"sasl", "security", b"security"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["no_auth", b"no_auth", "sasl", b"sasl", "security", b"security"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["security", b"security"]) -> typing.Literal["sasl", "no_auth"] | None: ...

global___KafkaAuth = KafkaAuth

@typing.final
class KafkaSaslSecurity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_FIELD_NUMBER: builtins.int
    MECHANISM_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    user: builtins.str
    """User name"""
    mechanism: global___KafkaMechanism.ValueType
    """SASL mechanism for authentication"""
    @property
    def password(self) -> yandex.cloud.datatransfer.v1.endpoint.common_pb2.Secret:
        """Password for user"""

    def __init__(
        self,
        *,
        user: builtins.str = ...,
        mechanism: global___KafkaMechanism.ValueType = ...,
        password: yandex.cloud.datatransfer.v1.endpoint.common_pb2.Secret | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["password", b"password"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["mechanism", b"mechanism", "password", b"password", "user", b"user"]) -> None: ...

global___KafkaSaslSecurity = KafkaSaslSecurity

@typing.final
class KafkaSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTION_FIELD_NUMBER: builtins.int
    AUTH_FIELD_NUMBER: builtins.int
    SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    TOPIC_NAME_FIELD_NUMBER: builtins.int
    TRANSFORMER_FIELD_NUMBER: builtins.int
    PARSER_FIELD_NUMBER: builtins.int
    TOPIC_NAMES_FIELD_NUMBER: builtins.int
    topic_name: builtins.str
    """Full source topic name
    Deprecated in favor of topic names
    """
    @property
    def connection(self) -> global___KafkaConnectionOptions:
        """Connection settings"""

    @property
    def auth(self) -> global___KafkaAuth:
        """Authentication settings"""

    @property
    def security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Security groups"""

    @property
    def transformer(self) -> yandex.cloud.datatransfer.v1.endpoint.common_pb2.DataTransformationOptions:
        """Data transformation rules"""

    @property
    def parser(self) -> yandex.cloud.datatransfer.v1.endpoint.parsers_pb2.Parser:
        """Data parsing rules"""

    @property
    def topic_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of topic names to read"""

    def __init__(
        self,
        *,
        connection: global___KafkaConnectionOptions | None = ...,
        auth: global___KafkaAuth | None = ...,
        security_groups: collections.abc.Iterable[builtins.str] | None = ...,
        topic_name: builtins.str = ...,
        transformer: yandex.cloud.datatransfer.v1.endpoint.common_pb2.DataTransformationOptions | None = ...,
        parser: yandex.cloud.datatransfer.v1.endpoint.parsers_pb2.Parser | None = ...,
        topic_names: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["auth", b"auth", "connection", b"connection", "parser", b"parser", "transformer", b"transformer"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["auth", b"auth", "connection", b"connection", "parser", b"parser", "security_groups", b"security_groups", "topic_name", b"topic_name", "topic_names", b"topic_names", "transformer", b"transformer"]) -> None: ...

global___KafkaSource = KafkaSource

@typing.final
class KafkaTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTION_FIELD_NUMBER: builtins.int
    AUTH_FIELD_NUMBER: builtins.int
    SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    TOPIC_SETTINGS_FIELD_NUMBER: builtins.int
    SERIALIZER_FIELD_NUMBER: builtins.int
    @property
    def connection(self) -> global___KafkaConnectionOptions:
        """Connection settings"""

    @property
    def auth(self) -> global___KafkaAuth:
        """Authentication settings"""

    @property
    def security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Security groups"""

    @property
    def topic_settings(self) -> global___KafkaTargetTopicSettings:
        """Target topic settings"""

    @property
    def serializer(self) -> yandex.cloud.datatransfer.v1.endpoint.serializers_pb2.Serializer:
        """Data serialization format settings"""

    def __init__(
        self,
        *,
        connection: global___KafkaConnectionOptions | None = ...,
        auth: global___KafkaAuth | None = ...,
        security_groups: collections.abc.Iterable[builtins.str] | None = ...,
        topic_settings: global___KafkaTargetTopicSettings | None = ...,
        serializer: yandex.cloud.datatransfer.v1.endpoint.serializers_pb2.Serializer | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["auth", b"auth", "connection", b"connection", "serializer", b"serializer", "topic_settings", b"topic_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["auth", b"auth", "connection", b"connection", "security_groups", b"security_groups", "serializer", b"serializer", "topic_settings", b"topic_settings"]) -> None: ...

global___KafkaTarget = KafkaTarget

@typing.final
class KafkaTargetTopicSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOPIC_FIELD_NUMBER: builtins.int
    TOPIC_PREFIX_FIELD_NUMBER: builtins.int
    topic_prefix: builtins.str
    """Topic prefix

    Analogue of the Debezium setting database.server.name.
    Messages will be sent to topic with name <topic_prefix>.<schema>.<table_name>.
    """
    @property
    def topic(self) -> global___KafkaTargetTopic:
        """Full topic name"""

    def __init__(
        self,
        *,
        topic: global___KafkaTargetTopic | None = ...,
        topic_prefix: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["topic", b"topic", "topic_prefix", b"topic_prefix", "topic_settings", b"topic_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["topic", b"topic", "topic_prefix", b"topic_prefix", "topic_settings", b"topic_settings"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["topic_settings", b"topic_settings"]) -> typing.Literal["topic", "topic_prefix"] | None: ...

global___KafkaTargetTopicSettings = KafkaTargetTopicSettings

@typing.final
class KafkaTargetTopic(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOPIC_NAME_FIELD_NUMBER: builtins.int
    SAVE_TX_ORDER_FIELD_NUMBER: builtins.int
    topic_name: builtins.str
    """Topic name"""
    save_tx_order: builtins.bool
    """Save transactions order
    Not to split events queue into separate per-table queues.
    """
    def __init__(
        self,
        *,
        topic_name: builtins.str = ...,
        save_tx_order: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["save_tx_order", b"save_tx_order", "topic_name", b"topic_name"]) -> None: ...

global___KafkaTargetTopic = KafkaTargetTopic



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class SecurityProfile(google.protobuf.message.Message):
    """A SecurityProfile resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _DefaultAction:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _DefaultActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[SecurityProfile._DefaultAction.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        DEFAULT_ACTION_UNSPECIFIED: SecurityProfile._DefaultAction.ValueType  # 0
        ALLOW: SecurityProfile._DefaultAction.ValueType  # 1
        """Pass request to service."""
        DENY: SecurityProfile._DefaultAction.ValueType  # 2
        """Deny request."""

    class DefaultAction(_DefaultAction, metaclass=_DefaultActionEnumTypeWrapper):
        """Action to perform if none of rules matched."""

    DEFAULT_ACTION_UNSPECIFIED: SecurityProfile.DefaultAction.ValueType  # 0
    ALLOW: SecurityProfile.DefaultAction.ValueType  # 1
    """Pass request to service."""
    DENY: SecurityProfile.DefaultAction.ValueType  # 2
    """Deny request."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CLOUD_ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DEFAULT_ACTION_FIELD_NUMBER: builtins.int
    SECURITY_RULES_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    CAPTCHA_ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the security profile."""
    folder_id: builtins.str
    """ID of the folder that the security profile belongs to."""
    cloud_id: builtins.str
    """ID of the cloud that the security profile belongs to."""
    name: builtins.str
    """Name of the security profile. The name is unique within the folder. 1-50 characters long."""
    description: builtins.str
    """Optional description of the security profile."""
    default_action: global___SecurityProfile.DefaultAction.ValueType
    """Action to perform if none of rules matched."""
    captcha_id: builtins.str
    """Captcha ID to use with this security profile. Set empty to use default."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Labels as `` key:value `` pairs. Maximum of 64 per resource."""

    @property
    def security_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SecurityRule]:
        """List of security rules."""

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp in [RFC3339](https://www.ietf.org/rfc/rfc3339.txt) text format."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        cloud_id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        default_action: global___SecurityProfile.DefaultAction.ValueType = ...,
        security_rules: collections.abc.Iterable[global___SecurityRule] | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        captcha_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["captcha_id", b"captcha_id", "cloud_id", b"cloud_id", "created_at", b"created_at", "default_action", b"default_action", "description", b"description", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "name", b"name", "security_rules", b"security_rules"]) -> None: ...

global___SecurityProfile = SecurityProfile

@typing.final
class SecurityRule(google.protobuf.message.Message):
    """A SecurityRule object, see [Rules](/docs/smartwebsecurity/concepts/rules)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class RuleCondition(google.protobuf.message.Message):
        """RuleCondition object."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _Action:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _ActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[SecurityRule.RuleCondition._Action.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            ACTION_UNSPECIFIED: SecurityRule.RuleCondition._Action.ValueType  # 0
            ALLOW: SecurityRule.RuleCondition._Action.ValueType  # 1
            """Pass request to service."""
            DENY: SecurityRule.RuleCondition._Action.ValueType  # 2
            """Deny request."""

        class Action(_Action, metaclass=_ActionEnumTypeWrapper):
            """Type of action to perform if this rule matched."""

        ACTION_UNSPECIFIED: SecurityRule.RuleCondition.Action.ValueType  # 0
        ALLOW: SecurityRule.RuleCondition.Action.ValueType  # 1
        """Pass request to service."""
        DENY: SecurityRule.RuleCondition.Action.ValueType  # 2
        """Deny request."""

        ACTION_FIELD_NUMBER: builtins.int
        CONDITION_FIELD_NUMBER: builtins.int
        action: global___SecurityRule.RuleCondition.Action.ValueType
        """Action to perform if this rule matched."""
        @property
        def condition(self) -> global___Condition:
            """The condition for matching the rule."""

        def __init__(
            self,
            *,
            action: global___SecurityRule.RuleCondition.Action.ValueType = ...,
            condition: global___Condition | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["condition", b"condition"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["action", b"action", "condition", b"condition"]) -> None: ...

    @typing.final
    class SmartProtection(google.protobuf.message.Message):
        """SmartProtection object."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _Mode:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _ModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[SecurityRule.SmartProtection._Mode.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            MODE_UNSPECIFIED: SecurityRule.SmartProtection._Mode.ValueType  # 0
            FULL: SecurityRule.SmartProtection._Mode.ValueType  # 1
            """Full protection means that the traffic will be checked based on ML models and behavioral analysis,
            with suspicious requests being sent to SmartCaptcha.
            """
            API: SecurityRule.SmartProtection._Mode.ValueType  # 2
            """API protection means checking the traffic based on ML models and behavioral analysis without sending suspicious
            requests to SmartCaptcha. The suspicious requests will be blocked.
            """

        class Mode(_Mode, metaclass=_ModeEnumTypeWrapper):
            """Mode of protection."""

        MODE_UNSPECIFIED: SecurityRule.SmartProtection.Mode.ValueType  # 0
        FULL: SecurityRule.SmartProtection.Mode.ValueType  # 1
        """Full protection means that the traffic will be checked based on ML models and behavioral analysis,
        with suspicious requests being sent to SmartCaptcha.
        """
        API: SecurityRule.SmartProtection.Mode.ValueType  # 2
        """API protection means checking the traffic based on ML models and behavioral analysis without sending suspicious
        requests to SmartCaptcha. The suspicious requests will be blocked.
        """

        MODE_FIELD_NUMBER: builtins.int
        CONDITION_FIELD_NUMBER: builtins.int
        mode: global___SecurityRule.SmartProtection.Mode.ValueType
        """Mode of protection."""
        @property
        def condition(self) -> global___Condition:
            """The condition for matching the rule."""

        def __init__(
            self,
            *,
            mode: global___SecurityRule.SmartProtection.Mode.ValueType = ...,
            condition: global___Condition | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["condition", b"condition"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["condition", b"condition", "mode", b"mode"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    DRY_RUN_FIELD_NUMBER: builtins.int
    RULE_CONDITION_FIELD_NUMBER: builtins.int
    SMART_PROTECTION_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the rule. The name is unique within the folder. 1-50 characters long."""
    priority: builtins.int
    """Determines the priority for checking the incoming traffic.
    Enter an integer within the range of 1 and 999999.
    The rule priority must be unique within the entire security profile.
    A lower numeric value means a higher priority.
    The default_action has the lowest priority.
    """
    dry_run: builtins.bool
    """This mode allows you to test your security profile or a single rule.
    For example, you can have the number of alarms for a specific rule displayed.
    Note: if this option is true, no real action affecting your traffic regarding this rule will be taken.
    """
    description: builtins.str
    """Optional description of the rule. 0-512 characters long."""
    @property
    def rule_condition(self) -> global___SecurityRule.RuleCondition:
        """Rule actions, see [Rule actions](/docs/smartwebsecurity/concepts/rules#rule-action)."""

    @property
    def smart_protection(self) -> global___SecurityRule.SmartProtection:
        """Smart Protection rule, see [Smart Protection rules](/docs/smartwebsecurity/concepts/rules#smart-protection-rules)."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        priority: builtins.int = ...,
        dry_run: builtins.bool = ...,
        rule_condition: global___SecurityRule.RuleCondition | None = ...,
        smart_protection: global___SecurityRule.SmartProtection | None = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["rule_condition", b"rule_condition", "rule_specifier", b"rule_specifier", "smart_protection", b"smart_protection"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "dry_run", b"dry_run", "name", b"name", "priority", b"priority", "rule_condition", b"rule_condition", "rule_specifier", b"rule_specifier", "smart_protection", b"smart_protection"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["rule_specifier", b"rule_specifier"]) -> typing.Literal["rule_condition", "smart_protection"] | None: ...

global___SecurityRule = SecurityRule

@typing.final
class Condition(google.protobuf.message.Message):
    """Condition object. AND semantics implied.
    See [documentation](/docs/smartwebsecurity/concepts/conditions) for matchers description.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class StringMatcher(google.protobuf.message.Message):
        """StringMatcher object."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        EXACT_MATCH_FIELD_NUMBER: builtins.int
        EXACT_NOT_MATCH_FIELD_NUMBER: builtins.int
        PREFIX_MATCH_FIELD_NUMBER: builtins.int
        PREFIX_NOT_MATCH_FIELD_NUMBER: builtins.int
        PIRE_REGEX_MATCH_FIELD_NUMBER: builtins.int
        PIRE_REGEX_NOT_MATCH_FIELD_NUMBER: builtins.int
        exact_match: builtins.str
        exact_not_match: builtins.str
        prefix_match: builtins.str
        prefix_not_match: builtins.str
        pire_regex_match: builtins.str
        pire_regex_not_match: builtins.str
        def __init__(
            self,
            *,
            exact_match: builtins.str = ...,
            exact_not_match: builtins.str = ...,
            prefix_match: builtins.str = ...,
            prefix_not_match: builtins.str = ...,
            pire_regex_match: builtins.str = ...,
            pire_regex_not_match: builtins.str = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["exact_match", b"exact_match", "exact_not_match", b"exact_not_match", "match", b"match", "pire_regex_match", b"pire_regex_match", "pire_regex_not_match", b"pire_regex_not_match", "prefix_match", b"prefix_match", "prefix_not_match", b"prefix_not_match"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["exact_match", b"exact_match", "exact_not_match", b"exact_not_match", "match", b"match", "pire_regex_match", b"pire_regex_match", "pire_regex_not_match", b"pire_regex_not_match", "prefix_match", b"prefix_match", "prefix_not_match", b"prefix_not_match"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["match", b"match"]) -> typing.Literal["exact_match", "exact_not_match", "prefix_match", "prefix_not_match", "pire_regex_match", "pire_regex_not_match"] | None: ...

    @typing.final
    class HttpMethodMatcher(google.protobuf.message.Message):
        """HttpMethodMatcher object."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        HTTP_METHODS_FIELD_NUMBER: builtins.int
        @property
        def http_methods(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Condition.StringMatcher]:
            """List of HTTP methods. OR semantics implied."""

        def __init__(
            self,
            *,
            http_methods: collections.abc.Iterable[global___Condition.StringMatcher] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["http_methods", b"http_methods"]) -> None: ...

    @typing.final
    class AuthorityMatcher(google.protobuf.message.Message):
        """AuthorityMatcher object."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        AUTHORITIES_FIELD_NUMBER: builtins.int
        @property
        def authorities(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Condition.StringMatcher]:
            """List of authorities. OR semantics implied."""

        def __init__(
            self,
            *,
            authorities: collections.abc.Iterable[global___Condition.StringMatcher] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["authorities", b"authorities"]) -> None: ...

    @typing.final
    class RequestUriMatcher(google.protobuf.message.Message):
        """RequestUriMatcher object. AND semantics implied."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        PATH_FIELD_NUMBER: builtins.int
        QUERIES_FIELD_NUMBER: builtins.int
        @property
        def path(self) -> global___Condition.StringMatcher:
            """Path of the URI [RFC3986](https://datatracker.ietf.org/doc/html/rfc3986#section-3.3)."""

        @property
        def queries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Condition.QueryMatcher]:
            """List of query matchers. AND semantics implied."""

        def __init__(
            self,
            *,
            path: global___Condition.StringMatcher | None = ...,
            queries: collections.abc.Iterable[global___Condition.QueryMatcher] | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["path", b"path"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["path", b"path", "queries", b"queries"]) -> None: ...

    @typing.final
    class QueryMatcher(google.protobuf.message.Message):
        """QueryMatcher object."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        """Key of the query parameter."""
        @property
        def value(self) -> global___Condition.StringMatcher:
            """Value of the query parameter."""

        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___Condition.StringMatcher | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing.final
    class HeaderMatcher(google.protobuf.message.Message):
        """HeaderMatcher object."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NAME_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        name: builtins.str
        """Name of header (case insensitive)."""
        @property
        def value(self) -> global___Condition.StringMatcher:
            """Value of the header."""

        def __init__(
            self,
            *,
            name: builtins.str = ...,
            value: global___Condition.StringMatcher | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["name", b"name", "value", b"value"]) -> None: ...

    @typing.final
    class IpMatcher(google.protobuf.message.Message):
        """IpMatcher object. AND semantics implied."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        IP_RANGES_MATCH_FIELD_NUMBER: builtins.int
        IP_RANGES_NOT_MATCH_FIELD_NUMBER: builtins.int
        GEO_IP_MATCH_FIELD_NUMBER: builtins.int
        GEO_IP_NOT_MATCH_FIELD_NUMBER: builtins.int
        @property
        def ip_ranges_match(self) -> global___Condition.IpRangesMatcher: ...
        @property
        def ip_ranges_not_match(self) -> global___Condition.IpRangesMatcher: ...
        @property
        def geo_ip_match(self) -> global___Condition.GeoIpMatcher: ...
        @property
        def geo_ip_not_match(self) -> global___Condition.GeoIpMatcher: ...
        def __init__(
            self,
            *,
            ip_ranges_match: global___Condition.IpRangesMatcher | None = ...,
            ip_ranges_not_match: global___Condition.IpRangesMatcher | None = ...,
            geo_ip_match: global___Condition.GeoIpMatcher | None = ...,
            geo_ip_not_match: global___Condition.GeoIpMatcher | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["geo_ip_match", b"geo_ip_match", "geo_ip_not_match", b"geo_ip_not_match", "ip_ranges_match", b"ip_ranges_match", "ip_ranges_not_match", b"ip_ranges_not_match"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["geo_ip_match", b"geo_ip_match", "geo_ip_not_match", b"geo_ip_not_match", "ip_ranges_match", b"ip_ranges_match", "ip_ranges_not_match", b"ip_ranges_not_match"]) -> None: ...

    @typing.final
    class IpRangesMatcher(google.protobuf.message.Message):
        """IpRangesMatcher object."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        IP_RANGES_FIELD_NUMBER: builtins.int
        @property
        def ip_ranges(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """List of IP ranges. OR semantics implied.
            v4/v6 - allow, exact IP == /32 or /128 range
            """

        def __init__(
            self,
            *,
            ip_ranges: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["ip_ranges", b"ip_ranges"]) -> None: ...

    @typing.final
    class GeoIpMatcher(google.protobuf.message.Message):
        """GeoIpMatcher object."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        LOCATIONS_FIELD_NUMBER: builtins.int
        @property
        def locations(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """ISO 3166-1 alpha 2. OR semantics implied."""

        def __init__(
            self,
            *,
            locations: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["locations", b"locations"]) -> None: ...

    AUTHORITY_FIELD_NUMBER: builtins.int
    HTTP_METHOD_FIELD_NUMBER: builtins.int
    REQUEST_URI_FIELD_NUMBER: builtins.int
    HEADERS_FIELD_NUMBER: builtins.int
    SOURCE_IP_FIELD_NUMBER: builtins.int
    @property
    def authority(self) -> global___Condition.AuthorityMatcher:
        """Match authority (Host header)."""

    @property
    def http_method(self) -> global___Condition.HttpMethodMatcher:
        """Match HTTP method."""

    @property
    def request_uri(self) -> global___Condition.RequestUriMatcher:
        """Match Request URI."""

    @property
    def headers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Condition.HeaderMatcher]:
        """Match HTTP headers."""

    @property
    def source_ip(self) -> global___Condition.IpMatcher:
        """Match IP."""

    def __init__(
        self,
        *,
        authority: global___Condition.AuthorityMatcher | None = ...,
        http_method: global___Condition.HttpMethodMatcher | None = ...,
        request_uri: global___Condition.RequestUriMatcher | None = ...,
        headers: collections.abc.Iterable[global___Condition.HeaderMatcher] | None = ...,
        source_ip: global___Condition.IpMatcher | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["authority", b"authority", "http_method", b"http_method", "request_uri", b"request_uri", "source_ip", b"source_ip"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["authority", b"authority", "headers", b"headers", "http_method", b"http_method", "request_uri", b"request_uri", "source_ip", b"source_ip"]) -> None: ...

global___Condition = Condition



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.empty_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import yandex.cloud.datatransfer.v1.endpoint.common_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ClickhouseCleanupPolicy:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ClickhouseCleanupPolicyEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ClickhouseCleanupPolicy.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CLICKHOUSE_CLEANUP_POLICY_UNSPECIFIED: _ClickhouseCleanupPolicy.ValueType  # 0
    CLICKHOUSE_CLEANUP_POLICY_DISABLED: _ClickhouseCleanupPolicy.ValueType  # 1
    CLICKHOUSE_CLEANUP_POLICY_DROP: _ClickhouseCleanupPolicy.ValueType  # 2
    CLICKHOUSE_CLEANUP_POLICY_TRUNCATE: _ClickhouseCleanupPolicy.ValueType  # 3

class ClickhouseCleanupPolicy(_ClickhouseCleanupPolicy, metaclass=_ClickhouseCleanupPolicyEnumTypeWrapper): ...

CLICKHOUSE_CLEANUP_POLICY_UNSPECIFIED: ClickhouseCleanupPolicy.ValueType  # 0
CLICKHOUSE_CLEANUP_POLICY_DISABLED: ClickhouseCleanupPolicy.ValueType  # 1
CLICKHOUSE_CLEANUP_POLICY_DROP: ClickhouseCleanupPolicy.ValueType  # 2
CLICKHOUSE_CLEANUP_POLICY_TRUNCATE: ClickhouseCleanupPolicy.ValueType  # 3
global___ClickhouseCleanupPolicy = ClickhouseCleanupPolicy

@typing.final
class ClickhouseShard(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    HOSTS_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def hosts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        hosts: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["hosts", b"hosts", "name", b"name"]) -> None: ...

global___ClickhouseShard = ClickhouseShard

@typing.final
class OnPremiseClickhouse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHARDS_FIELD_NUMBER: builtins.int
    HTTP_PORT_FIELD_NUMBER: builtins.int
    NATIVE_PORT_FIELD_NUMBER: builtins.int
    TLS_MODE_FIELD_NUMBER: builtins.int
    http_port: builtins.int
    native_port: builtins.int
    @property
    def shards(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ClickhouseShard]: ...
    @property
    def tls_mode(self) -> yandex.cloud.datatransfer.v1.endpoint.common_pb2.TLSMode: ...
    def __init__(
        self,
        *,
        shards: collections.abc.Iterable[global___ClickhouseShard] | None = ...,
        http_port: builtins.int = ...,
        native_port: builtins.int = ...,
        tls_mode: yandex.cloud.datatransfer.v1.endpoint.common_pb2.TLSMode | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["tls_mode", b"tls_mode"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["http_port", b"http_port", "native_port", b"native_port", "shards", b"shards", "tls_mode", b"tls_mode"]) -> None: ...

global___OnPremiseClickhouse = OnPremiseClickhouse

@typing.final
class ClickhouseConnectionOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ON_PREMISE_FIELD_NUMBER: builtins.int
    MDB_CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    DATABASE_FIELD_NUMBER: builtins.int
    mdb_cluster_id: builtins.str
    user: builtins.str
    database: builtins.str
    """Database"""
    @property
    def on_premise(self) -> global___OnPremiseClickhouse: ...
    @property
    def password(self) -> yandex.cloud.datatransfer.v1.endpoint.common_pb2.Secret: ...
    def __init__(
        self,
        *,
        on_premise: global___OnPremiseClickhouse | None = ...,
        mdb_cluster_id: builtins.str = ...,
        user: builtins.str = ...,
        password: yandex.cloud.datatransfer.v1.endpoint.common_pb2.Secret | None = ...,
        database: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["address", b"address", "mdb_cluster_id", b"mdb_cluster_id", "on_premise", b"on_premise", "password", b"password"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["address", b"address", "database", b"database", "mdb_cluster_id", b"mdb_cluster_id", "on_premise", b"on_premise", "password", b"password", "user", b"user"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["address", b"address"]) -> typing.Literal["on_premise", "mdb_cluster_id"] | None: ...

global___ClickhouseConnectionOptions = ClickhouseConnectionOptions

@typing.final
class ClickhouseConnection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTION_OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def connection_options(self) -> global___ClickhouseConnectionOptions: ...
    def __init__(
        self,
        *,
        connection_options: global___ClickhouseConnectionOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["connection", b"connection", "connection_options", b"connection_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["connection", b"connection", "connection_options", b"connection_options"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["connection", b"connection"]) -> typing.Literal["connection_options"] | None: ...

global___ClickhouseConnection = ClickhouseConnection

@typing.final
class ClickhouseSharding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class ColumnValueHash(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        COLUMN_NAME_FIELD_NUMBER: builtins.int
        column_name: builtins.str
        def __init__(
            self,
            *,
            column_name: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["column_name", b"column_name"]) -> None: ...

    @typing.final
    class ColumnValueMapping(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class ValueToShard(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            COLUMN_VALUE_FIELD_NUMBER: builtins.int
            SHARD_NAME_FIELD_NUMBER: builtins.int
            shard_name: builtins.str
            @property
            def column_value(self) -> yandex.cloud.datatransfer.v1.endpoint.common_pb2.ColumnValue: ...
            def __init__(
                self,
                *,
                column_value: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ColumnValue | None = ...,
                shard_name: builtins.str = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["column_value", b"column_value"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["column_value", b"column_value", "shard_name", b"shard_name"]) -> None: ...

        COLUMN_NAME_FIELD_NUMBER: builtins.int
        MAPPING_FIELD_NUMBER: builtins.int
        column_name: builtins.str
        @property
        def mapping(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ClickhouseSharding.ColumnValueMapping.ValueToShard]: ...
        def __init__(
            self,
            *,
            column_name: builtins.str = ...,
            mapping: collections.abc.Iterable[global___ClickhouseSharding.ColumnValueMapping.ValueToShard] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["column_name", b"column_name", "mapping", b"mapping"]) -> None: ...

    COLUMN_VALUE_HASH_FIELD_NUMBER: builtins.int
    CUSTOM_MAPPING_FIELD_NUMBER: builtins.int
    TRANSFER_ID_FIELD_NUMBER: builtins.int
    ROUND_ROBIN_FIELD_NUMBER: builtins.int
    @property
    def column_value_hash(self) -> global___ClickhouseSharding.ColumnValueHash: ...
    @property
    def custom_mapping(self) -> global___ClickhouseSharding.ColumnValueMapping: ...
    @property
    def transfer_id(self) -> google.protobuf.empty_pb2.Empty: ...
    @property
    def round_robin(self) -> google.protobuf.empty_pb2.Empty: ...
    def __init__(
        self,
        *,
        column_value_hash: global___ClickhouseSharding.ColumnValueHash | None = ...,
        custom_mapping: global___ClickhouseSharding.ColumnValueMapping | None = ...,
        transfer_id: google.protobuf.empty_pb2.Empty | None = ...,
        round_robin: google.protobuf.empty_pb2.Empty | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["column_value_hash", b"column_value_hash", "custom_mapping", b"custom_mapping", "round_robin", b"round_robin", "sharding", b"sharding", "transfer_id", b"transfer_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["column_value_hash", b"column_value_hash", "custom_mapping", b"custom_mapping", "round_robin", b"round_robin", "sharding", b"sharding", "transfer_id", b"transfer_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["sharding", b"sharding"]) -> typing.Literal["column_value_hash", "custom_mapping", "transfer_id", "round_robin"] | None: ...

global___ClickhouseSharding = ClickhouseSharding

@typing.final
class ClickhouseSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTION_FIELD_NUMBER: builtins.int
    INCLUDE_TABLES_FIELD_NUMBER: builtins.int
    EXCLUDE_TABLES_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    subnet_id: builtins.str
    @property
    def connection(self) -> global___ClickhouseConnection: ...
    @property
    def include_tables(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """While list of tables for replication. If none or empty list is presented - will
        replicate all tables. Can contain * patterns.
        """

    @property
    def exclude_tables(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Exclude list of tables for replication. If none or empty list is presented -
        will replicate all tables. Can contain * patterns.
        """

    @property
    def security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        connection: global___ClickhouseConnection | None = ...,
        include_tables: collections.abc.Iterable[builtins.str] | None = ...,
        exclude_tables: collections.abc.Iterable[builtins.str] | None = ...,
        subnet_id: builtins.str = ...,
        security_groups: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["connection", b"connection"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["connection", b"connection", "exclude_tables", b"exclude_tables", "include_tables", b"include_tables", "security_groups", b"security_groups", "subnet_id", b"subnet_id"]) -> None: ...

global___ClickhouseSource = ClickhouseSource

@typing.final
class ClickhouseTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTION_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    ALT_NAMES_FIELD_NUMBER: builtins.int
    CLEANUP_POLICY_FIELD_NUMBER: builtins.int
    SHARDING_FIELD_NUMBER: builtins.int
    CLICKHOUSE_CLUSTER_NAME_FIELD_NUMBER: builtins.int
    SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    subnet_id: builtins.str
    cleanup_policy: global___ClickhouseCleanupPolicy.ValueType
    clickhouse_cluster_name: builtins.str
    @property
    def connection(self) -> global___ClickhouseConnection: ...
    @property
    def alt_names(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.datatransfer.v1.endpoint.common_pb2.AltName]:
        """Alternative table names in target"""

    @property
    def sharding(self) -> global___ClickhouseSharding: ...
    @property
    def security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        connection: global___ClickhouseConnection | None = ...,
        subnet_id: builtins.str = ...,
        alt_names: collections.abc.Iterable[yandex.cloud.datatransfer.v1.endpoint.common_pb2.AltName] | None = ...,
        cleanup_policy: global___ClickhouseCleanupPolicy.ValueType = ...,
        sharding: global___ClickhouseSharding | None = ...,
        clickhouse_cluster_name: builtins.str = ...,
        security_groups: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["connection", b"connection", "sharding", b"sharding"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["alt_names", b"alt_names", "cleanup_policy", b"cleanup_policy", "clickhouse_cluster_name", b"clickhouse_cluster_name", "connection", b"connection", "security_groups", b"security_groups", "sharding", b"sharding", "subnet_id", b"subnet_id"]) -> None: ...

global___ClickhouseTarget = ClickhouseTarget



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class AgentSelector(google.protobuf.message.Message):
    """Agent selection criterion.

    The structure is used by service to determine on which agents a specific test should be executed.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AGENT_ID_FIELD_NUMBER: builtins.int
    MATCH_BY_FILTER_FIELD_NUMBER: builtins.int
    ANONYMOUS_AGENT_FIELD_NUMBER: builtins.int
    agent_id: builtins.str
    """Selection by agent ID."""
    match_by_filter: builtins.str
    """Selection by filter string."""
    anonymous_agent: builtins.bool
    """Select anonymoud (i.e. not registered) agents."""
    def __init__(
        self,
        *,
        agent_id: builtins.str = ...,
        match_by_filter: builtins.str = ...,
        anonymous_agent: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["agent", b"agent", "agent_id", b"agent_id", "anonymous_agent", b"anonymous_agent", "match_by_filter", b"match_by_filter"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["agent", b"agent", "agent_id", b"agent_id", "anonymous_agent", b"anonymous_agent", "match_by_filter", b"match_by_filter"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["agent", b"agent"]) -> typing.Literal["agent_id", "match_by_filter", "anonymous_agent"] | None: ...

global___AgentSelector = AgentSelector



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/foundation_models/v1/text_classification/text_classification.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nRyandex/cloud/ai/foundation_models/v1/text_classification/text_classification.proto\x12\x38yandex.cloud.ai.foundation_models.v1.text_classification\"8\n\x13\x43lassificationLabel\x12\r\n\x05label\x18\x01 \x01(\t\x12\x12\n\nconfidence\x18\x02 \x01(\x01\"3\n\x14\x43lassificationSample\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\r\n\x05label\x18\x02 \x01(\tB\xb0\x01\n<yandex.cloud.api.ai.foundation_models.v1.text_classificationZpgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/foundation_models/v1/text_classification;text_classificationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.foundation_models.v1.text_classification.text_classification_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n<yandex.cloud.api.ai.foundation_models.v1.text_classificationZpgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/foundation_models/v1/text_classification;text_classification'
  _globals['_CLASSIFICATIONLABEL']._serialized_start=144
  _globals['_CLASSIFICATIONLABEL']._serialized_end=200
  _globals['_CLASSIFICATIONSAMPLE']._serialized_start=202
  _globals['_CLASSIFICATIONSAMPLE']._serialized_end=253
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/datatransfer/v1/transfer_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.datatransfer.v1 import transfer_pb2 as yandex_dot_cloud_dot_datatransfer_dot_v1_dot_transfer__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3yandex/cloud/datatransfer/v1/transfer_service.proto\x12\x1cyandex.cloud.datatransfer.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a+yandex/cloud/datatransfer/v1/transfer.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\"\xb1\x03\n\x15\x43reateTransferRequest\x12\x11\n\tsource_id\x18\x01 \x01(\t\x12\x11\n\ttarget_id\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x11\n\tfolder_id\x18\x04 \x01(\t\x12\x36\n\x07runtime\x18\x05 \x01(\x0b\x32%.yandex.cloud.datatransfer.v1.Runtime\x12\x38\n\x04type\x18\x06 \x01(\x0e\x32*.yandex.cloud.datatransfer.v1.TransferType\x12\x0c\n\x04name\x18\x07 \x01(\t\x12O\n\x06labels\x18\x08 \x03(\x0b\x32?.yandex.cloud.datatransfer.v1.CreateTransferRequest.LabelsEntry\x12\x44\n\x0etransformation\x18\n \x01(\x0b\x32,.yandex.cloud.datatransfer.v1.Transformation\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\t\x10\n\"-\n\x16\x43reateTransferMetadata\x12\x13\n\x0btransfer_id\x18\x01 \x01(\t\"\x84\x03\n\x15UpdateTransferRequest\x12\x13\n\x0btransfer_id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x36\n\x07runtime\x18\x03 \x01(\x0b\x32%.yandex.cloud.datatransfer.v1.Runtime\x12\x0c\n\x04name\x18\x04 \x01(\t\x12/\n\x0bupdate_mask\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12O\n\x06labels\x18\x06 \x03(\x0b\x32?.yandex.cloud.datatransfer.v1.UpdateTransferRequest.LabelsEntry\x12\x44\n\x0etransformation\x18\x08 \x01(\x0b\x32,.yandex.cloud.datatransfer.v1.Transformation\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x07\x10\x08\"-\n\x16UpdateTransferMetadata\x12\x13\n\x0btransfer_id\x18\x01 \x01(\t\",\n\x15\x44\x65leteTransferRequest\x12\x13\n\x0btransfer_id\x18\x01 \x01(\t\"-\n\x16\x44\x65leteTransferMetadata\x12\x13\n\x0btransfer_id\x18\x01 \x01(\t\"V\n\x14ListTransfersRequest\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12\x11\n\tpage_size\x18\x03 \x01(\x03\x12\x12\n\npage_token\x18\x04 \x01(\tJ\x04\x08\x01\x10\x02\"k\n\x15ListTransfersResponse\x12\x39\n\ttransfers\x18\x01 \x03(\x0b\x32&.yandex.cloud.datatransfer.v1.Transfer\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\")\n\x12GetTransferRequest\x12\x13\n\x0btransfer_id\x18\x01 \x01(\t\"0\n\x19\x44\x65\x61\x63tivateTransferRequest\x12\x13\n\x0btransfer_id\x18\x01 \x01(\t\"1\n\x1a\x44\x65\x61\x63tivateTransferMetadata\x12\x13\n\x0btransfer_id\x18\x01 \x01(\t\".\n\x17\x41\x63tivateTransferRequest\x12\x13\n\x0btransfer_id\x18\x01 \x01(\t\"/\n\x18\x41\x63tivateTransferMetadata\x12\x13\n\x0btransfer_id\x18\x01 \x01(\t2\xdd\t\n\x0fTransferService\x12\x9f\x01\n\x06\x43reate\x12\x33.yandex.cloud.datatransfer.v1.CreateTransferRequest\x1a!.yandex.cloud.operation.Operation\"=\xb2\xd2*\"\n\x16\x43reateTransferMetadata\x12\x08Transfer\x82\xd3\xe4\x93\x02\x11\"\x0c/v1/transfer:\x01*\x12\xad\x01\n\x06Update\x12\x33.yandex.cloud.datatransfer.v1.UpdateTransferRequest\x1a!.yandex.cloud.operation.Operation\"K\xb2\xd2*\"\n\x16UpdateTransferMetadata\x12\x08Transfer\x82\xd3\xe4\x93\x02\x1f\x32\x1a/v1/transfer/{transfer_id}:\x01*\x12\xb7\x01\n\x06\x44\x65lete\x12\x33.yandex.cloud.datatransfer.v1.DeleteTransferRequest\x1a!.yandex.cloud.operation.Operation\"U\xb2\xd2*/\n\x16\x44\x65leteTransferMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x1c*\x1a/v1/transfer/{transfer_id}\x12\x97\x01\n\x04List\x12\x32.yandex.cloud.datatransfer.v1.ListTransfersRequest\x1a\x33.yandex.cloud.datatransfer.v1.ListTransfersResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/v1/transfers/list/{folder_id}\x12\x83\x01\n\x03Get\x12\x30.yandex.cloud.datatransfer.v1.GetTransferRequest\x1a&.yandex.cloud.datatransfer.v1.Transfer\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v1/transfer/{transfer_id}\x12\xd1\x01\n\nDeactivate\x12\x37.yandex.cloud.datatransfer.v1.DeactivateTransferRequest\x1a!.yandex.cloud.operation.Operation\"g\xb2\xd2*3\n\x1a\x44\x65\x61\x63tivateTransferMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02*\"%/v1/transfer/{transfer_id}:deactivate:\x01*\x12\xc9\x01\n\x08\x41\x63tivate\x12\x35.yandex.cloud.datatransfer.v1.ActivateTransferRequest\x1a!.yandex.cloud.operation.Operation\"c\xb2\xd2*1\n\x18\x41\x63tivateTransferMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02(\"#/v1/transfer/{transfer_id}:activate:\x01*Bq\n yandex.cloud.api.datatransfer.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1;datatransferb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.datatransfer.v1.transfer_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n yandex.cloud.api.datatransfer.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1;datatransfer'
  _CREATETRANSFERREQUEST_LABELSENTRY._options = None
  _CREATETRANSFERREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATETRANSFERREQUEST_LABELSENTRY._options = None
  _UPDATETRANSFERREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _TRANSFERSERVICE.methods_by_name['Create']._options = None
  _TRANSFERSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*\"\n\026CreateTransferMetadata\022\010Transfer\202\323\344\223\002\021\"\014/v1/transfer:\001*'
  _TRANSFERSERVICE.methods_by_name['Update']._options = None
  _TRANSFERSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*\"\n\026UpdateTransferMetadata\022\010Transfer\202\323\344\223\002\0372\032/v1/transfer/{transfer_id}:\001*'
  _TRANSFERSERVICE.methods_by_name['Delete']._options = None
  _TRANSFERSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*/\n\026DeleteTransferMetadata\022\025google.protobuf.Empty\202\323\344\223\002\034*\032/v1/transfer/{transfer_id}'
  _TRANSFERSERVICE.methods_by_name['List']._options = None
  _TRANSFERSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002 \022\036/v1/transfers/list/{folder_id}'
  _TRANSFERSERVICE.methods_by_name['Get']._options = None
  _TRANSFERSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\034\022\032/v1/transfer/{transfer_id}'
  _TRANSFERSERVICE.methods_by_name['Deactivate']._options = None
  _TRANSFERSERVICE.methods_by_name['Deactivate']._serialized_options = b'\262\322*3\n\032DeactivateTransferMetadata\022\025google.protobuf.Empty\202\323\344\223\002*\"%/v1/transfer/{transfer_id}:deactivate:\001*'
  _TRANSFERSERVICE.methods_by_name['Activate']._options = None
  _TRANSFERSERVICE.methods_by_name['Activate']._serialized_options = b'\262\322*1\n\030ActivateTransferMetadata\022\025google.protobuf.Empty\202\323\344\223\002(\"#/v1/transfer/{transfer_id}:activate:\001*'
  _globals['_CREATETRANSFERREQUEST']._serialized_start=269
  _globals['_CREATETRANSFERREQUEST']._serialized_end=702
  _globals['_CREATETRANSFERREQUEST_LABELSENTRY']._serialized_start=651
  _globals['_CREATETRANSFERREQUEST_LABELSENTRY']._serialized_end=696
  _globals['_CREATETRANSFERMETADATA']._serialized_start=704
  _globals['_CREATETRANSFERMETADATA']._serialized_end=749
  _globals['_UPDATETRANSFERREQUEST']._serialized_start=752
  _globals['_UPDATETRANSFERREQUEST']._serialized_end=1140
  _globals['_UPDATETRANSFERREQUEST_LABELSENTRY']._serialized_start=651
  _globals['_UPDATETRANSFERREQUEST_LABELSENTRY']._serialized_end=696
  _globals['_UPDATETRANSFERMETADATA']._serialized_start=1142
  _globals['_UPDATETRANSFERMETADATA']._serialized_end=1187
  _globals['_DELETETRANSFERREQUEST']._serialized_start=1189
  _globals['_DELETETRANSFERREQUEST']._serialized_end=1233
  _globals['_DELETETRANSFERMETADATA']._serialized_start=1235
  _globals['_DELETETRANSFERMETADATA']._serialized_end=1280
  _globals['_LISTTRANSFERSREQUEST']._serialized_start=1282
  _globals['_LISTTRANSFERSREQUEST']._serialized_end=1368
  _globals['_LISTTRANSFERSRESPONSE']._serialized_start=1370
  _globals['_LISTTRANSFERSRESPONSE']._serialized_end=1477
  _globals['_GETTRANSFERREQUEST']._serialized_start=1479
  _globals['_GETTRANSFERREQUEST']._serialized_end=1520
  _globals['_DEACTIVATETRANSFERREQUEST']._serialized_start=1522
  _globals['_DEACTIVATETRANSFERREQUEST']._serialized_end=1570
  _globals['_DEACTIVATETRANSFERMETADATA']._serialized_start=1572
  _globals['_DEACTIVATETRANSFERMETADATA']._serialized_end=1621
  _globals['_ACTIVATETRANSFERREQUEST']._serialized_start=1623
  _globals['_ACTIVATETRANSFERREQUEST']._serialized_end=1669
  _globals['_ACTIVATETRANSFERMETADATA']._serialized_start=1671
  _globals['_ACTIVATETRANSFERMETADATA']._serialized_end=1718
  _globals['_TRANSFERSERVICE']._serialized_start=1721
  _globals['_TRANSFERSERVICE']._serialized_end=2966
# @@protoc_insertion_point(module_scope)
